import { RouterView } from 'vue-router';

const parkingCard = {
    name: 'ParkingCard',
    path: ':id',
    component: () => import('src/pages/Shelving/Parking/Card/ParkingCard.vue'),
    redirect: { name: 'ParkingSummary' },
    meta: {
        menu: ['ParkingBasicData', 'ParkingLog'],
    },
    children: [
        {
            path: 'summary',
            name: 'ParkingSummary',
            meta: {
                title: 'summary',
                icon: 'launch',
            },
            component: () => import('src/pages/Shelving/Parking/Card/ParkingSummary.vue'),
        },
        {
            path: 'basic-data',
            name: 'ParkingBasicData',
            meta: {
                title: 'basicData',
                icon: 'vn:settings',
            },
            component: () =>
                import('src/pages/Shelving/Parking/Card/ParkingBasicData.vue'),
        },
        {
            path: 'log',
            name: 'ParkingLog',
            meta: {
                title: 'log',
                icon: 'history',
            },
            component: () => import('src/pages/Shelving/Parking/Card/ParkingLog.vue'),
        },
    ],
};

const shelvingCard = {
    name: 'ShelvingLayout',
    path: ':id',
    component: () => import('pages/Shelving/Card/ShelvingCard.vue'),
    redirect: { name: 'ShelvingSummary' },
    meta: { menu: ['ShelvingBasicData', 'ShelvingLog'] },
    children: [
        {
            name: 'ShelvingSummary',
            path: 'summary',
            meta: {
                title: 'summary',
            },
            component: () => import('pages/Shelving/Card/ShelvingSummary.vue'),
        },
        {
            name: 'ShelvingBasicData',
            path: 'basic-data',
            meta: {
                title: 'basicData',
                icon: 'vn:settings',
            },
            component: () => import('pages/Shelving/Card/ShelvingForm.vue'),
        },
        {
            name: 'ShelvingLog',
            path: 'log',
            meta: {
                title: 'log',
                icon: 'history',
            },
            component: () => import('src/pages/Shelving/Card/ShelvingLog.vue'),
        },
    ],
};

export default {
    path: '/shelving',
    name: 'Shelving',
    meta: {
        title: 'shelving',
        icon: 'vn:inventory',
        moduleName: 'Shelving',
        menu: ['ShelvingList', 'ParkingMain'],
    },
    component: RouterView,
    redirect: { name: 'ShelvingMain' },
    children: [
        {
            path: '',
            name: 'ShelvingMain',
            component: () => import('src/components/common/VnModule.vue'),
            redirect: { name: 'ShelvingSection' },
            children: [
                {
                    path: '',
                    name: 'ShelvingSection',
                    redirect: { name: 'ShelvingList' },
                    component: () => import('src/pages/Shelving/ShelvingList.vue'),
                    children: [
                        {
                            path: 'list',
                            name: 'ShelvingList',
                            meta: {
                                title: 'list',
                                icon: 'view_list',
                            },
                        },
                        shelvingCard,
                    ],
                },
                {
                    path: 'create',
                    name: 'ShelvingCreate',
                    meta: {
                        title: 'shelvingCreate',
                        icon: 'add',
                    },
                    component: () => import('src/pages/Shelving/Card/ShelvingForm.vue'),
                },
                {
                    path: 'parking',
                    name: 'ParkingMain',
                    redirect: { name: 'ParkingList' },
                    meta: {
                        title: 'parkingList',
                        icon: 'view_list',
                    },
                    component: () => import('src/pages/Shelving/Parking/ParkingList.vue'),
                    children: [
                        {
                            path: 'list',
                            name: 'ParkingList',
                        },
                        parkingCard,
                    ],
                },
            ],
        },
    ],
};
